@@ -1,6 +1,6 @@
 package BibTeX::Parser;
 {
-  $BibTeX::Parser::VERSION = '0.69';
+  $BibTeX::Parser::VERSION = '0.70';
 }
 # ABSTRACT: A pure perl BibTeX parser
 use warnings;
@@ -84,7 +84,7 @@ sub _parse_next {
             pos($_) = $pos;
 
             if ( $type eq "STRING" ) {
-                if (/\G{\s*($re_name)\s*=\s*/cgo) {
+                if (/\G\{\s*($re_name)\s*=\s*/cgo) {
                     my $key   = $1;
                     my $value = _parse_string( $self->{strings} );
                     if ( defined $self->{strings}->{$key} ) {
@@ -337,7 +337,7 @@ L<BibTeX::Parser::Author>
 
 =head1 VERSION
 
-version 0.69
+version 0.70
 
 
 =head1 AUTHOR
